@@ -4,6 +4,15 @@
 
 
 """
+2022/5/10
+control_version:0.5.10
+blcoklyFile_version:2.2.6
+blockly_version:2.2.2
+修改视觉和机器学习
+"""
+
+"""
+2022/5/9
 control_version:0.5.9
 blcoklyFile_version:2.2.6
 blockly_version:2.2.2
