@@ -323,7 +323,7 @@ class CSB(object):
     def __wait_for_e(self, value: bool, timeout: int):
         '''
         必要的时延
-        :param value:
+        :param value
         :param timeout: 毫秒级时延
         :return:
         '''
@@ -506,7 +506,7 @@ class HongWai(object):
 class Servo():  # 采用PCA9685芯片提供稳定的PWM波，弃用树莓派的模拟PWM波
     def __init__(self, pin):
         self.MIN_IMP = 500
-        self.MAX_IMP = 2500
+        self.MAX_IMP = 2460
         self.servo_io = PWM2GPIO[pin]
         GPIO.cleanup(self.servo_io)  # 清空PWM口
         self.pca = ServoKit(channels=16)
@@ -516,7 +516,7 @@ class Servo():  # 采用PCA9685芯片提供稳定的PWM波，弃用树莓派的
 
     def init_servo(self):
         self.pca.servo[self.servo_io].set_pulse_width_range(self.MIN_IMP, self.MAX_IMP)  # 设置PWM口电平宽度
-        self.pca.servo[self.servo_io].angle = 0
+        self.pca.servo[self.servo_io].angle = 180
         time.sleep(0.01)
         self.angle = 0
         print("已完成舵机初始化")
@@ -547,7 +547,7 @@ class Servo():  # 采用PCA9685芯片提供稳定的PWM波，弃用树莓派的
                 else:
                     self.fa = 'True'
                     curr_angle -= delta
-            self.pca.servo[self.servo_io].angle = curr_angle
+            self.pca.servo[self.servo_io].angle = 180-curr_angle
             time.sleep(0.05)
             diff_angle = abs(curr_angle - angle1)
         self.angle = curr_angle
